@@ -29,59 +29,59 @@ details_dict = {
     "/wes/r1_.fastq.gz": FileDetails("source"),
     "/wes/r2_.fastq.gz": FileDetails("source"),
     "/wes/reads_.bam": FileDetails("source"),
-    ## see: https://github.com/CIMAC-CIDC/cidc-ngs-pipeline-api/blob/master/wes/wes_output_API.json
-    "/wes/analysis/vcfcompare.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/optimalpurityvalue.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/clonality_pyclone.tsv": FileDetails("miscellaneous"),
-    "/wes/analysis/copynumber_cnvcalls.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/copynumber_cnvcalls.txt.tn.tsv": FileDetails("miscellaneous"),
-    "/wes/analysis/MHC_Class_I_all_epitopes.tsv": FileDetails("miscellaneous"),
-    "/wes/analysis/MHC_Class_I_filtered_condensed_ranked.tsv": FileDetails(
-        "miscellaneous"
-    ),
-    "/wes/analysis/MHC_Class_II_all_epitopes.tsv": FileDetails("miscellaneous"),
-    "/wes/analysis/MHC_Class_II_filtered_condensed_ranked.tsv": FileDetails(
-        "miscellaneous"
-    ),
-    "/wes/analysis/vcf_tnscope_output.vcf": FileDetails("miscellaneous"),
-    "/wes/analysis/maf_tnscope_output.maf": FileDetails("miscellaneous"),
-    "/wes/analysis/vcf_tnscope_filter.vcf": FileDetails("miscellaneous"),
-    "/wes/analysis/maf_tnscope_filter.maf": FileDetails("miscellaneous"),
-    "/wes/analysis/tnscope_exons_broad.gz": FileDetails("miscellaneous"),
-    "/wes/analysis/tnscope_exons_mda.gz": FileDetails("miscellaneous"),
-    "/wes/analysis/tnscope_exons_mocha.gz": FileDetails("miscellaneous"),
-    "/wes/analysis/tn_corealigned.bam": FileDetails("miscellaneous"),
-    "/wes/analysis/tn_corealigned.bam.bai": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/recalibrated.bam": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/recalibrated.bam.bai": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/sorted.dedup.bam": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/sorted.dedup.bam.bai": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/recalibrated.bam": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/recalibrated.bam.bai": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/sorted.dedup.bam": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/sorted.dedup.bam.bai": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/coverage_metrics.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/target_metrics.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/coverage_metrics_summary.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/target_metrics_summary.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/mosdepth_region_dist_broad.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/mosdepth_region_dist_mda.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/mosdepth_region_dist_mocha.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/coverage_metrics.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/target_metrics.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/coverage_metrics_summary.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/target_metrics_summary.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/mosdepth_region_dist_broad.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/mosdepth_region_dist_mda.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/mosdepth_region_dist_mocha.txt": FileDetails("miscellaneous"),
-    "/wes/analysis/tumor/optitype_result.tsv": FileDetails("miscellaneous"),
-    "/wes/analysis/normal/optitype_result.tsv": FileDetails("miscellaneous"),
+    # see: https://github.com/CIMAC-CIDC/cidc-ngs-pipeline-api/blob/master/cidc_ngs_pipeline_api/wes/wes_output_API.json
+    # Germline
+    "/wes/analysis/vcfcompare.txt": FileDetails("analysis"),
+    "/wes/analysis/tumor/haplotyper_targets.vcf.gz": FileDetails("analysis"),
+    "/wes/analysis/normal/haplotyper_targets.vcf.gz": FileDetails("analysis"),
+    # Purity
+    "/wes/analysis/optimal_purity_value.txt": FileDetails("analysis"),
+    # Clonality
+    "/wes/analysis/clonality_pyclone.tsv": FileDetails("analysis"),
+    "/wes/analysis/clonality_table.tsv": FileDetails("analysis"),
+    # Copy number
+    "/wes/analysis/copynumber_cnvcalls.txt": FileDetails("analysis"),
+    "/wes/analysis/copynumber_cnvcalls.txt.tn.tsv": FileDetails("analysis"),
+    # Neoantigen
+    "/wes/analysis/HLA_results.tsv": FileDetails("analysis"),
+    "/wes/analysis/combined_filtered.tsv": FileDetails("analysis"),
+    # Somatic
+    "/wes/analysis/vcf_gz_tnscope_output.vcf.gz": FileDetails("analysis"),
+    "/wes/analysis/maf_tnscope_output.maf": FileDetails("analysis"),
+    "/wes/analysis/vcf_gz_tnscope_filter.vcf.gz": FileDetails("analysis"),
+    "/wes/analysis/maf_tnscope_filter.maf": FileDetails("analysis"),
+    "/wes/analysis/tnscope_exons_broad.vcf.gz": FileDetails("analysis"),
+    "/wes/analysis/tnscope_exons_mda.vcf.gz": FileDetails("analysis"),
+    "/wes/analysis/tnscope_exons_mocha.vcf.gz": FileDetails("analysis"),
+    # Alignment
+    "/wes/analysis/tumor/sorted.dedup.bam": FileDetails("analysis"),
+    "/wes/analysis/tumor/sorted.dedup.bam.bai": FileDetails("analysis"),
+    "/wes/analysis/normal/sorted.dedup.bam": FileDetails("analysis"),
+    "/wes/analysis/normal/sorted.dedup.bam.bai": FileDetails("analysis"),
+    # Metrics
+    "/wes/analysis/tumor/coverage_metrics.txt": FileDetails("analysis"),
+    "/wes/analysis/tumor/target_metrics.txt": FileDetails("analysis"),
+    "/wes/analysis/tumor/coverage_metrics_summary.txt": FileDetails("analysis"),
+    "/wes/analysis/normal/coverage_metrics.txt": FileDetails("analysis"),
+    "/wes/analysis/normal/target_metrics.txt": FileDetails("analysis"),
+    "/wes/analysis/normal/coverage_metrics_summary.txt": FileDetails("analysis"),
+    # HLA type
+    "/wes/analysis/tumor/optitype_result.tsv": FileDetails("analysis"),
+    "/wes/analysis/normal/optitype_result.tsv": FileDetails("analysis"),
+    # Report
     "/wes/analysis/wes_version.txt": FileDetails("miscellaneous"),
+    "/wes/analysis/tumor_mutational_burden.tsv": FileDetails("analysis"),
+    "/wes/analysis/report.tar.gz": FileDetails("analysis"),
+    "/wes/analysis/wes_run_version.tsv": FileDetails("miscellaneous"),
+    "/wes/analysis/config.yaml": FileDetails("miscellaneous"),
+    "/wes/analysis/metasheet.csv": FileDetails("miscellaneous"),
+    "/wes/analysis/wes_sample.json": FileDetails("analysis"),
+    "/wes/analysis/xhla_report_hla.json": FileDetails("analysis"),
     # RNA
     "/rna/r1_.fastq.gz": FileDetails("source"),
     "/rna/r2_.fastq.gz": FileDetails("source"),
     "/rna/reads_.bam": FileDetails("source"),
-    ## see: https://github.com/CIMAC-CIDC/cidc-ngs-pipeline-api/blob/master/rna/rna_level1_output_API.json
+    # see: https://github.com/CIMAC-CIDC/cidc-ngs-pipeline-api/blob/master/cidc_ngs_pipeline_api/rna/rna_output_API.json
     "/rna/analysis/star/sorted.bam": FileDetails("analysis"),
     "/rna/analysis/star/sorted.bam.bai": FileDetails("miscellaneous"),
     "/rna/analysis/star/sorted.bam.stat.txt": FileDetails("miscellaneous"),
